@@ -11,7 +11,7 @@ import sys
 
 from tuxsuite import __version__
 from tuxsuite.cli.config import load_config
-from tuxsuite.cli.utils import error
+from tuxsuite.cli.utils import error, get_remote_version
 from tuxsuite.cli.bake import (
     handlers as bake_handlers,
     setup_parser as bake_parser,
@@ -52,6 +52,13 @@ def setup_parser():
         "--version", action="version", version=f"%(prog)s, {__version__}"
     )
 
+    parser.add_argument(
+        "--remote-version",
+        help="show remote backend tools version",
+        default=False,
+        action="store_true",
+    )
+
     sub_parser = parser.add_subparsers(dest="command", help="Command")
     sub_parser.required = True
 
@@ -126,6 +133,16 @@ def main():
             elif sys.argv[1] == "test" and sys.argv[2] not in cmds["test"]:
                 sys.argv.insert(2, "submit")
 
+    # fetch remote backend tools version
+    if "--remote-version" in sys.argv:
+        versions = get_remote_version(load_config())
+        print(
+            f"tuxbake: {versions.get('versions').get('tuxbake')}\n"
+            f"tuxmake: {versions.get('versions').get('tuxmake')}\n"
+            f"tuxrun: {versions.get('versions').get('tuxrun')}"
+        )
+        sys.exit(0)
+
     (options, extra_arguments) = parser.parse_known_args()
 
     cfg = load_config()
